﻿using System;
using DevExpress.ExpressApp;
using DevExpress.ExpressApp.Actions;
using DevExpress.ExpressApp.SystemModule;
using DevExpress.ExpressApp.Templates.ActionControls;
using DevExpress.ExpressApp.Win.Templates.Bars.ActionControls;
using DevExpress.ExpressApp.Win.Templates.Ribbon.ActionControls;
using DevExpress.XtraBars;
using Xafari.Actions;

namespace Solution2.Module.Win.Controllers
{
	public class CustomActionControlController : Controller
	{
		private void actionControlsSiteController_CustomAddActionControlToContainer(object sender, CustomAddActionControlEventArgs e)
		{
			if (e.Action is AggregatedAction)
			{
				if (e.Container is BarLinkActionControlContainer)
				{
					BarLinkActionControlContainer container = (BarLinkActionControlContainer)e.Container;
					IActionControl actionControl = CreateActionControl(container,e.Action, container.BarContainerItem, container.IsMenuMode);
					container.AddActionControl(actionControl);
					e.Handled = true;
				}
				if (e.Container is RibbonGroupActionControlContainer)
				{
					RibbonGroupActionControlContainer container = (RibbonGroupActionControlContainer)e.Container;
					IActionControl actionControl = CreateActionControl(container, e.Action, container.RibbonGroup.ItemLinks, container.IsMenuMode);
					container.AddActionControl(actionControl);
					e.Handled = true;
				}
			}
		}

		private IActionControl CreateActionControl(IActionControlContainer container, ActionBase action, BarLinksHolder barLinksHolder, bool isMenuMode)
		{
			return AddSingleChoiceActionControl(container, barLinksHolder, action.Id, action.GetFormattedConfirmationMessage(),((ChoiceActionBase)action).IsHierarchical(), ((SingleChoiceAction)action).ItemType, isMenuMode);
		}

		public ISingleChoiceActionControl AddSingleChoiceActionControl(IActionControlContainer container, BarLinksHolder barLinksHolder, string actionId, string aggregatedActionConfirmationMessage, bool isHierarchical, SingleChoiceActionItemType itemType, bool isMenuMode)
		{
			if (!isHierarchical && itemType == SingleChoiceActionItemType.ItemIsMode && !isMenuMode)
				container.AddSingleChoiceActionControl(actionId, isHierarchical, itemType);
			return this.AddBarButtonItemSingleChoiceActionControl(actionId, itemType, barLinksHolder,aggregatedActionConfirmationMessage);
		}

		public ISingleChoiceActionControl AddBarButtonItemSingleChoiceActionControl(string actionId, SingleChoiceActionItemType itemType, BarLinksHolder barLinksHolder, string aggregatedActionConfirmationMessage)
		{
			BarButtonItem buttonItem = new BarButtonItem();
			buttonItem.Manager = barLinksHolder.Manager;
			barLinksHolder.AddItem((BarItem)buttonItem);
			CustomBarButtonItemSingleChoiceActionControl choiceActionControl = new CustomBarButtonItemSingleChoiceActionControl();
			choiceActionControl.AggregatedActionConfirmationMessage = aggregatedActionConfirmationMessage;
			choiceActionControl.BeginInit();
			choiceActionControl.ActionId = actionId;
			choiceActionControl.BarItem = buttonItem;
			choiceActionControl.ItemType = itemType;
			choiceActionControl.EndInit();
			return (ISingleChoiceActionControl)choiceActionControl;
		}

		protected override void OnActivated()
		{
			base.OnActivated();
			ActionControlsSiteController actionControlsSiteController = Frame.GetController<ActionControlsSiteController>();
			if (actionControlsSiteController != null)
			{
				actionControlsSiteController.CustomAddActionControlToContainer += new EventHandler<CustomAddActionControlEventArgs>(actionControlsSiteController_CustomAddActionControlToContainer);
			}
		}
		protected override void OnDeactivated()
		{
			ActionControlsSiteController actionControlsSiteController = Frame.GetController<ActionControlsSiteController>();
			if (actionControlsSiteController != null)
			{
				actionControlsSiteController.CustomAddActionControlToContainer -= new EventHandler<CustomAddActionControlEventArgs>(actionControlsSiteController_CustomAddActionControlToContainer);
			}
			base.OnDeactivated();
		}
	}
}
